@@ -1,7 +1,6 @@
 from __future__ import with_statement
 from contextlib import nested
 from decorator import decorator
-from functools import wraps
 import argparse
 import codecs
 import inspect
@@ -9,6 +8,8 @@ import re
 import sys
 import logging
 
+__version__ = '0.0.1'
+
 """
     This is a library of decorators designed for writing scripts quickly. This
     means they are not the most sustainable tools that exist, but they do what
@@ -55,7 +56,6 @@ import logging
                 print >>sys.stderr, "line %s" % lineno
 """
 
-__version__ = '0.0.0'
 
 ENCODING='utf8'
 
@@ -129,6 +129,16 @@ def _parse_doc(docs):
     if docs:
 
         for line in docs.split("\n"):
+            
+            line = line.strip()
+
+            #remove starting ':param'
+            if line.startswith(':param'):
+                line = line[len(':param'):]
+
+            #skip ':rtype:' row
+            if line.startswith(':rtype:'):
+                continue
 
             if line.strip() == "----":
                 break
@@ -251,12 +261,16 @@ def signature_parser(func):
     parser = argparse.ArgumentParser(description=description, epilog=epilog, formatter_class=ParagraphPreservingArgParseFormatter)
 
     # special flags
-    #special_flags=['debug']
-    special_flags=['version','debug']
-    params += special_flags
-    defaults += (False,False,)
-    helps['version']="show program's version number and exit"
+    special_flags=[]
+    
+    special_flags += ['debug']
+    defaults += (False,)
     helps['debug'] = 'set logging level to DEBUG'
+    if module_version(func):
+        special_flags += ['version']
+        defaults += (False,)
+        helps['version']="show program's version number and exit"
+    params += special_flags
     
     # Optional flag options
     used_shorts = set()
@@ -439,7 +453,8 @@ def acceptargv(func):
                 #if kwargs.get('version'):
                 #    print module_version(func)
                 #    return
-                del kwargs['version']
+                if 'version' in kwargs.keys():
+                    del kwargs['version']
                 
                 # --debug
                 if kwargs.get('debug'):
@@ -453,6 +468,11 @@ def acceptargv(func):
                     return func(**kwargs)
             except UsageError, e:
                 parser.error(e.message)
+    
+    main.__doc__ = func.__doc__
+    main.__name__ = func.__name__
+    main.__module__ = func.__module__
+    main.__dict__ = func.__dict__.copy()
 
     return main
 
